@@ -1,11 +1,14 @@
 ﻿from __future__ import absolute_import
-from . import core
-from .core import *
+from hedaro.core.main import (
+get_sublist3r,
+get_amass,
+get_subdomains,
+)
  
 
 """hedaro - A pentesting library for Python"""
 
-__version__ = '0.0.1'
+__version__ = '0.0.4'
 __author__ = 'David Rojas <david@hedaro.com>'
 __all__ = []
 
